#!/usr/bin/env python3

import sys
import os
from homer import Config

def main():
    db = Config(app="about")

    if len(sys.argv) == 3:
        filename = sys.argv[1]
        comment  = sys.argv[2]
        if os.path.exists(filename) and comment != "":
            filename = os.path.abspath(filename)
            db[filename] = comment
        elif os.path.exists(filename) and comment == "":
            filename = os.path.abspath(filename)
            del db[filename]
        else:
            print("ERROR: File {} not exists!")
            sys.exit(1)
    else:
        dirname = os.getenv("PWD")
        dir_info = db.get(dirname, "Information about the {} directory".format(dirname))
        print("")
        print("# {}".format(dir_info))
        for i in db.search("{}/".format(dirname)):
            file = i[0]
            content = db[file]
            file = file.replace(dirname + "/", "")
            print(" * {} : {}".format(file, content))
        print("")
        print("--")
        print("Autogen by about - https://github.com/manoelhc/about")



#!/usr/bin/env python3

from distutils.core import setup

version = "0.0.1"

setup(
    name = 'about_file',
    packages = ['about'],
    license = 'MIT',
    version = version,
    description = 'About is a note tool that helps you describe files in your project.',
    author = 'Manoel Carvalho',
    author_email = 'manoelhc@gmail.com',
    url = 'https://github.com/manoelhc/about',
    download_url = 'https://github.com/manoelhc/about',
    keywords = ['testing', 'configuration'],
    install_requires=[
        'homer'
    ],
    classifiers = [
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6'
    ],
    entry_points={
            'console_scripts': [
                'about=about:main',
            ],
    }
)
